RegisterAddonMessagePrefix("HavenLootsNew");
RegisterAddonMessagePrefix("HavenLootsRoll");
RegisterAddonMessagePrefix("HavenLootsRes");
RegisterAddonMessagePrefix("HavenLootsClear");

--##########################################################################
-- class variables
local sendType = "RAID";

--##########################################################################
-- master looter check
local function IsMasterLooter()
	local _, _, ID = GetLootMethod();
	if ID == nil or UnitName("raid" ..ID) ~= UnitName("player") then
		return false;
	end
	return true;
end

local enterWorld = CreateFrame("FRAME");
enterWorld:RegisterEvent("PLAYER_ENTERING_WORLD");
local function EnterWorld(self, event)
	if HavenLootsServer_alts == nil then HavenLootsServer_alts = {} end
end
enterWorld:SetScript("OnEvent", EnterWorld)

--##########################################################################
-- add loot rolls
local function AddLootRoll(itemLink, name, rollType)
	SendAddonMessage("HavenLootsRes", name .."_"..rollType .."_" ..math.random(100) + ((5 - rollType) * 100) .."_" ..itemLink, sendType);
end

--##########################################################################
-- send loot table
local tooltip = CreateFrame('GameTooltip', 'HavenLootsTooltip', UIParent, 'GameTooltipTemplate');
tooltip:SetOwner(UIParent, "ANCHOR_NONE");

function GetItemBindType(link)
	tooltip:ClearLines();
	tooltip:SetHyperlink(link);
	local value = (GetCVar('colorblindMode') == '1' and HavenLootsTooltipTextLeft4 or HavenLootsTooltipTextLeft3):GetText();
	if value == "Binds when picked up" then
		return 1;
	else
		return 0;
	end
end

local function LootOpened()
	if IsMasterLooter() ~= true then return end
	for i = 1, 20 do
		local link = GetLootSlotLink(i);
		if link ~= nil then
			local bindOnPickUp = GetItemBindType(link);
			if bindOnPickUp == 1 then
				SendAddonMessage("HavenLootsNew", link .."_" ..1, sendType);
			else
				SendAddonMessage("HavenLootsNew", link .."_" ..0, sendType);
			end
		end
	end
end

--##########################################################################
-- recieve messages
local function IsAlt(name)
	words = {}
	for word in name:gmatch("([^-]+)") do table.insert(words, word) end
	for i = 1, table.getn(HavenLootsServer_alts) do
		if HavenLootsServer_alts[i] == words[1] then
			return true;
		end
	end
	return false;
end

local getRoll = CreateFrame("FRAME");
getRoll:RegisterEvent("CHAT_MSG_ADDON");
local function GetRoll(self, event, prefix, message, channel, sender)
	if IsMasterLooter() ~= true then return end
	if prefix == "HavenLootsRoll" then
		words = {}
		for word in message:gmatch("([^_]+)") do table.insert(words, word) end
		local itemLink = words[1];
		local rollType = tonumber(words[2]);
		if IsAlt(sender) then
			if rollType > 2 then
				rollType = rollType - 1;
			end
		end
		AddLootRoll(itemLink, sender, rollType);
	end
end
getRoll:SetScript("OnEvent", GetRoll)

--##########################################################################
-- set alts
local function NameIsInRaid(input)
	for i = 1, 40 do
		local name = GetRaidRosterInfo(i);
		if name == input then
			return true;
		end
	end
	return false;
end

local function TakeFromAlt(input)
	for i = 1, table.getn(HavenLootsServer_alts) do
		if HavenLootsServer_alts[i] == input then
			table.remove(HavenLootsServer_alts, i);
			return true;
		end
	end
	return false;
end

SLASH_HLS1 = '/hls';
function SlashCmdList.HLS(msg, editbox)
	if IsMasterLooter() ~= true then return end
	words = {}
	for word in msg:gmatch("[^%s]+") do table.insert(words, word) end
	if words[1] == "alt" then
		table.insert(HavenLootsServer_alts, GetUnitName("target", false));
		SendChatMessage("[Haven Loots] You have been marked as an alt! This means you will be given a lower priority on loot rolls. Roll as if you were a main and the addon will do the rest. Whisper me if this is incorrect!", "WHISPER", "Common", GetUnitName("target", true));
		DEFAULT_CHAT_FRAME:AddMessage("[HavenLoots]: " ..GetUnitName("target", false) .." added to alts.", 1, 1, 0);
	end
	if words[1] == "altremove" then
		local success = TakeFromAlt(GetUnitName("target", false));
		if success then
			SendChatMessage("[Haven Loots] You are no longer marked as an alt. Lucky you!", "WHISPER", "Common", GetUnitName("target", true));
			DEFAULT_CHAT_FRAME:AddMessage("[HavenLoots]: " ..GetUnitName("target", false) .." cleared from alts.", 1, 1, 0);
		else
			DEFAULT_CHAT_FRAME:AddMessage("[HavenLoots]: Error! No one in the current list of alts under that name.", 1, 0, 0);
		end
	end
	if words[1] == "altclear" then
		alts = {};
		DEFAULT_CHAT_FRAME:AddMessage("[HavenLoots]: Alts Cleared", 1, 1, 0);
		SendChatMessage("[Haven Loots] All alts have been reset! If you were one before you aren't now.", "RAID", "Common");
	end
	if words[1] == "roll" then
		SendAddonMessage("HavenLootsClear", "_", sendType);
		LootOpened();
		SendChatMessage("[Haven Loots] New loot data has been sent! If you do not have the Haven Loots addon you will not see this data.", "RAID", "Common");
		DEFAULT_CHAT_FRAME:AddMessage("[HavenLoots]: Loot broadcast sent.", 1, 1, 0);
	end
end
--##########################################################################